@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # django false-positives:
-# pylint: disable=E1123,E1120
+# pylint: disable=unexpected-keyword-arg,no-value-for-parameter
 from __future__ import unicode_literals
 
 import os
@@ -274,7 +274,9 @@ class Changes(debian.deb822.Changes):
 
     def tar(self, tar_path, add_files=None):
         with contextlib.closing(tarfile.open(tar_path, "w")) as tar:
-            tar_add = lambda f: tar.add(f, arcname=os.path.basename(f))
+            def tar_add(file_name):
+                tar.add(file_name, arcname=os.path.basename(file_name))
+
             tar_add(self._file_path)
             for f in self.get_files():
                 tar_add(os.path.join(os.path.dirname(self._file_path), f["name"]))
@@ -424,9 +426,3 @@ Build request failed: {r} ({s}): {e}
             bres.add_file(buildlog)
             bres.save(gnupg)
             bres.upload(hopo)
-
-
-if __name__ == "__main__":
-    mini_buildd.misc.setup_console_logging()
-    import doctest
-    doctest.testmod()
